@@ -1,7 +1,7 @@
 ;;; riffle.el --- template of list browser with immediate preview
-;;; Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+;;; Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
 ;;;   HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
-;;; $Id: riffle.el,v 1.41 2011-12-31 15:07:29 hira Exp $
+;;; $Id: riffle.el,v 1.42 2012-12-29 08:57:18 hira Exp $
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -94,10 +94,10 @@ even if you delete other windows explicitly."
 ;; derived-mode-merge-syntax-tables, which takes long time.
 ;; To avoid it, we need ":syntax-table nil". Sigh...
 
-(put 'riffle-define-derived-mode 'lisp-indent-hook 3)
 (defmacro riffle-define-derived-mode (child parent name
                                             &optional docstring
                                             &rest body)
+  (declare (indent 3))
   `(define-derived-mode ,child ,parent ,name
      ,docstring
      :syntax-table nil
@@ -324,7 +324,7 @@ This function returns effective value of ITEM-LIST."
   (let ((n (riffle-contents-item-number (point))))
     (riffle-summary (riffle-name) (riffle-item-list) riffle-type)
 ;    (howm-view-summary (riffle-name) (riffle-item-list))
-    (goto-line (1+ n)))) ;; top = 1 for goto-line
+    (howm-goto-line (1+ n)))) ;; top = 1 for goto-line
 
 (defun riffle-contents-goto-next-item (&optional n)
   (interactive "p")
@@ -466,7 +466,7 @@ snap://Info-mode/emacs#File Variables
 
 ;; 'Place' is line number at now
 (defun riffle-set-place (place)
-  (goto-line place))
+  (howm-goto-line place))
 (defun riffle-get-place (&optional point)
   (riffle-line-number point))
 
